@@ -1,7 +1,7 @@
 package Mojo::Util::Collection;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -32,7 +32,7 @@ has 'model' => sub {
 has 'objects' => sub {
     my $self = shift;
 
-    my @objects = map { $self->new_object(%{$_ || {}}) } @{ $self->items || [] };
+    my @objects = map { $self->newObject(%{$_ || {}}) } @{ $self->items || [] };
 
     return \@objects;
 };
@@ -42,6 +42,9 @@ has 'objects' => sub {
 
 Add an object
 
+Returns:
+C<Collection> of C<Model> objects
+
 =cut
 
 sub add {
@@ -56,7 +59,7 @@ sub add {
     my @objects = @{ $self->objects };
 
     if (ref($object) eq 'HASH') {
-        push(@objects, $self->new_object(%$object));
+        push(@objects, $self->newObject(%$object));
     } elsif (blessed($object)) {
         if ($object->isa('Mojo::Util::Collection')) {
             push(@objects, @{ $object->objects });
@@ -86,14 +89,17 @@ sub asOptions {
     return $self->formatter->asOptions($self->objects, @_);
 }
 
-=head2 as_options
+=head2 avg
 
-Return an array ref containing { value => $value, key => $label }
+Return the average value for given $field
 
 =cut
 
-sub as_options {
-    return shift->asOptions(@_);
+sub avg {
+    my ($self, $field) = @_;
+    my $values = $self->lists($field);
+
+    return List::Util::sum(@$values) / scalar(@$values);
 }
 
 =head2 count
@@ -199,7 +205,7 @@ sub findOrNew {
 
     my %new_args = (%{ $args || {} }, %{ $extra || {} });
 
-    return $self->find($args) || $self->new_object(%new_args);
+    return $self->find($args) || $self->newObject(%new_args);
 }
 
 =head2 first
@@ -227,7 +233,7 @@ C<Model> object
 sub firstOrNew {
     my ($self, $args) = @_;
 
-    return $self->first || $self->new_object(%$args);
+    return $self->first || $self->newObject(%$args);
 }
 
 =head2 get
@@ -258,7 +264,7 @@ sub indexOf {
     my @objects = @{ $self->objects };
 
     if (ref($object) ne ref($self->model)) {
-        $object = $self->new_object(%$object);
+        $object = $self->newObject(%$object);
     }
 
     for (my $i = 0; $i < scalar(@objects); $i++) {
@@ -307,7 +313,33 @@ sub lists {
     return \@fields;
 }
 
-=head2 new_object
+=head2 max
+
+Return the maximum value for given $field
+
+=cut
+
+sub max {
+    my ($self, $field) = @_;
+    my $values = $self->lists($field);
+
+    return List::Util::max(@$values);
+}
+
+=head2 min
+
+Return the minimum value for given $field
+
+=cut
+
+sub min {
+    my ($self, $field) = @_;
+    my $values = $self->lists($field);
+
+    return List::Util::min(@$values);
+}
+
+=head2 newObject
 
 Instantiate new object
 
@@ -316,7 +348,7 @@ C<Model> object
 
 =cut
 
-sub new_object {
+sub newObject {
     my $self = shift;
 
     return $self->model->new(@_);
@@ -401,16 +433,6 @@ sub orderBy {
     return $self;
 }
 
-=head2 order_by
-
-Order collection
-
-=cut
-
-sub order_by {
-    return shift->orderBy(@_);
-}
-
 =head2 page
 
 Take a collection containing only the results from a given page
@@ -428,9 +450,7 @@ sub page {
     my $start = ($page - 1) * $self->limit;
     my $end = List::Util::min(($page * $self->limit), scalar(@objects)) - 1;
 
-    my @partition = @objects[$start .. $end];
-
-    return $self->new({ objects => \@partition, model => $self->model });
+    retun $self->slice($start, $end);
 }
 
 =head2 remove
@@ -452,9 +472,7 @@ sub remove {
 
     # Remove only if exists
     if ($self->indexOf($object) >= 0) {
-        splice(@objects, $self->indexOf($object), 1);
-
-        $self->objects(\@objects);
+        return $self->splice($self->indexOf($object), 1);
     }
 
     return $self;
@@ -516,6 +534,29 @@ sub slice {
     return $self->new({ objects => \@partition, model => $self->model });
 }
 
+=head2 splice
+
+Splice objects
+
+=cut
+
+sub splice {
+    my ($self, $offset, $length) = @_;
+
+    if (! $length) {
+        $length = $offset || 1;
+        $offset = 0;
+    }
+
+    my @objects = @{ $self->objects };
+
+    splice(@objects, $offset, $length);
+
+    $self->objects(\@objects);
+
+    return $self;
+}
+
 =head2 sum
 
 Sum by $field
@@ -529,16 +570,16 @@ sub sum {
     return List::Util::sum(@$values);
 }
 
-=head2 serialize
+=head2 toArray
 
-Serialize all the objects
+Convert collection to array ref
 
 =cut
 
-sub serialize {
+sub toArray {
     my $self = shift;
 
-    return $self->formatter->serialize($self->objects);
+    return $self->formatter->toArray($self->objects, @_);
 }
 
 =head2 toCsv
@@ -553,16 +594,6 @@ sub toCsv {
     return $self->formatter->toCsv($self->objects, @_);
 }
 
-=head2 to_csv
-
-Convert collection to CSV string
-
-=cut
-
-sub to_csv {
-    return shift->toCsv(@_);
-}
-
 =head2 toJson
 
 Convert collection to JSON string
@@ -575,16 +606,6 @@ sub toJson {
     return $self->formatter->toJson($self->objects, @_);
 }
 
-=head2 to_json
-
-Convert collection to JSON string
-
-=cut
-
-sub to_json {
-    return shift->toJson(@_);
-}
-
 =head2 touch
 
 Touch collections model
