@@ -1,7 +1,7 @@
 package Mojo::Util::Collection::Formatter;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 
 use Mojo::JSON qw(encode_json);
 
@@ -27,16 +27,16 @@ sub asOptions {
     return $options;
 }
 
-=head2 serialize
+=head2 toArray
 
-Serialize all the objects
+Convert objects to array ref
 
 =cut
 
-sub serialize {
-    my ($self, $objects) = @_;
+sub toArray {
+    my ($self, $objects) = (shift, shift);
 
-    return [map { $_->serialize } @$objects];
+    return [map { $_->serialize(@_) } @$objects];
 }
 
 =head2 toCsv
@@ -64,7 +64,7 @@ Convert collection to JSON string
 sub toJson {
     my $self = shift;
 
-    return encode_json($self->serialize(@_));
+    return encode_json($self->toArray(@_));
 }
 
 1;
